Contributing to NeoJsonRPC
##########################

Thank you for contributing to NeoJsonRPC! A list of simple rules is available on the online
documentation to help you contribute to this project:
https://neojsonrpc.readthedocs.io/en/stable/contributing.html
